pub struct Pts(/* private fields */);Expand description
The child end of the pty
See open and Command::spawn
Implementations
Sourceimpl Pts
impl Pts
Sourcepub unsafe fn from_fd(fd: OwnedFd) -> Self
pub unsafe fn from_fd(fd: OwnedFd) -> Self
Use the provided file descriptor as a pts.
Safety
The provided file descriptor must be valid, open, and belong to the child end of a pty.
pub fn setup_subprocess(&self) -> Result<(Stdio, Stdio, Stdio)>
pub fn session_leader(&self) -> impl FnMut() -> Result<()> + use<>